@@ -551,6 +551,7 @@ pub enum PackageManager {
     Flatpak,
     Snap,
     Android,
+    Pkg,
 }
 
 impl ToString for PackageManager {
@@ -571,6 +572,7 @@ impl ToString for PackageManager {
             PackageManager::Flatpak => "flatpak",
             PackageManager::Snap => "snap",
             PackageManager::Android => "Android",
+            PackageManager::Pkg => "pkg",
         })
     }
 }
